/**
 * Copyright (c) 2007, 2010, 2013, 2021 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 * Alexander Shatalin (Borland) - initial API and implementation
 * Michael Golubev (Montages) - #386838 - migrate to Xtend2
 * Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : 1.4 Merge papyrus extension templates into codegen.xtend
 * Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : L1.2 clean up
 */
package xpt.navigator;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenEditorGenerator;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenNavigator;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenNavigatorChildReference;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenPlugin;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import plugin.Activator;
import xpt.CodeStyle;
import xpt.Common;
import xpt.editor.VisualIDRegistry;

@Singleton
@SuppressWarnings("all")
public class NavigatorLinkHelper {
  @Inject
  @Extension
  private CodeStyle _codeStyle;
  
  @Inject
  @Extension
  private Common _common;
  
  @Inject
  @Extension
  private Utils_qvto _utils_qvto;
  
  @Inject
  private Activator xptActivator;
  
  @Inject
  private getEditorInput xptGetEditorInput;
  
  @Inject
  private NavigatorAbstractNavigatorItem abstractNavigatorItem;
  
  @Inject
  private NavigatorGroup navigatorGroup;
  
  @Inject
  private NavigatorItem xptNavigatorItem;
  
  public CharSequence className(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    String _linkHelperClassName = it.getLinkHelperClassName();
    _builder.append(_linkHelperClassName);
    return _builder;
  }
  
  public CharSequence packageName(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    String _packageName = it.getPackageName();
    _builder.append(_packageName);
    return _builder;
  }
  
  public CharSequence qualifiedClassName(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(".");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    return _builder;
  }
  
  public CharSequence fullPath(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence NavigatorLinkHelper(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _copyright = this._common.copyright(it.getEditorGen());
    _builder.append(_copyright);
    _builder.newLineIfNotEmpty();
    _builder.append("package ");
    CharSequence _packageName = this.packageName(it);
    _builder.append(_packageName);
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _generatedClassComment = this._common.generatedClassComment();
    _builder.append(_generatedClassComment);
    _builder.newLineIfNotEmpty();
    _builder.append("public class ");
    CharSequence _className = this.className(it);
    _builder.append(_className);
    _builder.append(" implements org.eclipse.ui.navigator.ILinkHelper {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _editorInput = this.xptGetEditorInput.getEditorInput(it.getEditorGen());
    _builder.append(_editorInput, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _findSelection = this.findSelection(it);
    _builder.append(_findSelection, "\t");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _activateEditor = this.activateEditor(it);
    _builder.append(_activateEditor, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence findSelection(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    CharSequence _overrideI = this._codeStyle.overrideI(it);
    _builder.append(_overrideI);
    _builder.newLineIfNotEmpty();
    _builder.append("public org.eclipse.jface.viewers.IStructuredSelection findSelection(org.eclipse.ui.IEditorInput anInput) {");
    _builder.newLine();
    {
      GenNavigatorChildReference _diagramTopReference = this._utils_qvto.getDiagramTopReference(it);
      boolean _tripleNotEquals = (_diagramTopReference != null);
      if (_tripleNotEquals) {
        _builder.append("\t");
        CharSequence _defineDiagramDocument = this.defineDiagramDocument(it.getEditorGen().getPlugin());
        _builder.append(_defineDiagramDocument, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("\t");
    CharSequence _findSelectionBody = this.findSelectionBody(it);
    _builder.append(_findSelectionBody, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence defineDiagramDocument(final GenPlugin it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.gmf.runtime.diagram.ui.resources.editor.document.IDiagramDocument document = ");
    CharSequence _qualifiedClassName = this.xptActivator.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    _builder.append(".getInstance().getDocumentProvider().getDiagramDocument(anInput);");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence findSelectionBody(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      GenNavigatorChildReference _diagramTopReference = this._utils_qvto.getDiagramTopReference(it);
      boolean _tripleNotEquals = (_diagramTopReference != null);
      if (_tripleNotEquals) {
        CharSequence _diagramSelection = this.getDiagramSelection(this._utils_qvto.getDiagramTopReference(it));
        _builder.append(_diagramSelection);
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("return org.eclipse.jface.viewers.StructuredSelection.EMPTY;");
    _builder.newLine();
    return _builder;
  }
  
  /**
   * Linking with editor currently supported only for the navigators conteining top
   * reference to the diagram. In this case diagram node will be selected in navigator.
   */
  public CharSequence getDiagramSelection(final GenNavigatorChildReference it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _diagram = this.getDiagram(it.getNavigator().getEditorGen());
    _builder.append(_diagram);
    _builder.newLineIfNotEmpty();
    _builder.append("if (diagram == null || diagram.eResource() == null) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return org.eclipse.jface.viewers.StructuredSelection.EMPTY;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.append("org.eclipse.core.resources.IFile file = org.eclipse.emf.workspace.util.WorkspaceSynchronizer.getFile(diagram.eResource());");
    _builder.newLine();
    _builder.append("if (file != null) {");
    _builder.newLine();
    {
      boolean _isInsideGroup = it.isInsideGroup();
      if (_isInsideGroup) {
        _builder.append("\t");
        CharSequence _qualifiedClassName = this.navigatorGroup.qualifiedClassName(it.getNavigator());
        _builder.append(_qualifiedClassName, "\t");
        _builder.append(" parentGroup = new ");
        CharSequence _qualifiedClassName_1 = this.navigatorGroup.qualifiedClassName(it.getNavigator());
        _builder.append(_qualifiedClassName_1, "\t");
        _builder.append("(\"");
        String _groupName = it.getGroupName();
        _builder.append(_groupName, "\t");
        _builder.append("\", \"");
        String _groupIcon = it.getGroupIcon();
        _builder.append(_groupIcon, "\t");
        _builder.append("\", ");
        CharSequence _modelID = VisualIDRegistry.modelID(it.getNavigator().getEditorGen().getDiagram());
        _builder.append(_modelID, "\t");
        _builder.append(", file);");
        _builder.newLineIfNotEmpty();
      }
    }
    _builder.append("\t");
    CharSequence _qualifiedClassName_2 = this.xptNavigatorItem.qualifiedClassName(it.getNavigator());
    _builder.append(_qualifiedClassName_2, "\t");
    _builder.append(" item = new ");
    CharSequence _qualifiedClassName_3 = this.xptNavigatorItem.qualifiedClassName(it.getNavigator());
    _builder.append(_qualifiedClassName_3, "\t");
    _builder.append("(diagram, ");
    {
      boolean _isInsideGroup_1 = it.isInsideGroup();
      if (_isInsideGroup_1) {
        _builder.append("parentGroup");
      } else {
        _builder.append("file");
      }
    }
    _builder.append(", false);");
    _builder.newLineIfNotEmpty();
    {
      boolean _isInsideGroup_2 = it.isInsideGroup();
      if (_isInsideGroup_2) {
        _builder.append("\t");
        _builder.append("parentGroup.addChild(item);");
        _builder.newLine();
      }
    }
    _builder.append("\t");
    _builder.append("return new org.eclipse.jface.viewers.StructuredSelection(");
    {
      boolean _isInsideGroup_3 = it.isInsideGroup();
      if (_isInsideGroup_3) {
        _builder.append("parentGroup");
      } else {
        _builder.append("item");
      }
    }
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence getDiagram(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("if (document == null) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("return org.eclipse.jface.viewers.StructuredSelection.EMPTY;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    _builder.append("org.eclipse.gmf.runtime.notation.Diagram diagram = document.getDiagram();");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence activateEditor(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    CharSequence _overrideI = this._codeStyle.overrideI(it);
    _builder.append(_overrideI);
    _builder.newLineIfNotEmpty();
    _builder.append("public void activateEditor(org.eclipse.ui.IWorkbenchPage aPage, org.eclipse.jface.viewers.IStructuredSelection aSelection) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (aSelection == null || aSelection.isEmpty()) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (false == aSelection.getFirstElement() instanceof ");
    CharSequence _qualifiedClassName = this.abstractNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName, "\t");
    _builder.append(") {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("return;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    _builder.append("\t");
    CharSequence _qualifiedClassName_1 = this.abstractNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_1, "\t");
    _builder.append(" abstractNavigatorItem = (");
    CharSequence _qualifiedClassName_2 = this.abstractNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_2, "\t");
    _builder.append(") aSelection.getFirstElement();");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("org.eclipse.gmf.runtime.notation.View navigatorView = null;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (abstractNavigatorItem instanceof ");
    CharSequence _qualifiedClassName_3 = this.xptNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_3, "\t");
    _builder.append(") {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("navigatorView = ((");
    CharSequence _qualifiedClassName_4 = this.xptNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_4, "\t\t");
    _builder.append(") abstractNavigatorItem).getView();");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("} else if (abstractNavigatorItem instanceof ");
    CharSequence _qualifiedClassName_5 = this.navigatorGroup.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_5, "\t");
    _builder.append(") {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    CharSequence _qualifiedClassName_6 = this.navigatorGroup.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_6, "\t\t");
    _builder.append(" navigatorGroup = (");
    CharSequence _qualifiedClassName_7 = this.navigatorGroup.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_7, "\t\t");
    _builder.append(") abstractNavigatorItem;");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("if (navigatorGroup.getParent() instanceof ");
    CharSequence _qualifiedClassName_8 = this.xptNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_8, "\t\t");
    _builder.append(") {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t\t");
    _builder.append("navigatorView = ((");
    CharSequence _qualifiedClassName_9 = this.xptNavigatorItem.qualifiedClassName(it);
    _builder.append(_qualifiedClassName_9, "\t\t\t");
    _builder.append(") navigatorGroup.getParent()).getView();");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("}");
    CharSequence _viewFromShortcut = this.getViewFromShortcut(it);
    _builder.append(_viewFromShortcut, "\t\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (navigatorView == null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.ui.IEditorInput editorInput = getEditorInput(navigatorView.getDiagram());");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.ui.IEditorPart editor = aPage.findEditor(editorInput);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (editor == null) {");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("return;");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("aPage.bringToTop(editor);");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("if (editor instanceof ");
    CharSequence _diagramEditorClassFQName = this.diagramEditorClassFQName(it);
    _builder.append(_diagramEditorClassFQName, "\t");
    _builder.append(") {");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    CharSequence _diagramEditorClassFQName_1 = this.diagramEditorClassFQName(it);
    _builder.append(_diagramEditorClassFQName_1, "\t\t");
    _builder.append(" diagramEditor = (");
    CharSequence _diagramEditorClassFQName_2 = this.diagramEditorClassFQName(it);
    _builder.append(_diagramEditorClassFQName_2, "\t\t");
    _builder.append(") editor;");
    _builder.newLineIfNotEmpty();
    _builder.append("\t\t");
    _builder.append("org.eclipse.emf.ecore.resource.ResourceSet diagramEditorResourceSet = diagramEditor.getEditingDomain().getResourceSet();");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.eclipse.emf.ecore.EObject selectedView = diagramEditorResourceSet.getEObject(org.eclipse.emf.ecore.util.EcoreUtil.getURI(navigatorView), true);\t");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("if (selectedView == null) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("return;");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.eclipse.gef.GraphicalViewer graphicalViewer = (org.eclipse.gef.GraphicalViewer) diagramEditor.getAdapter(org.eclipse.gef.GraphicalViewer.class);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("org.eclipse.gef.EditPart selectedEditPart = (org.eclipse.gef.EditPart) graphicalViewer.getEditPartRegistry().get(selectedView);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("if (selectedEditPart != null) {");
    _builder.newLine();
    _builder.append("\t\t\t");
    _builder.append("graphicalViewer.select(selectedEditPart);");
    _builder.newLine();
    _builder.append("\t\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }
  
  public CharSequence getViewFromShortcut(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _generateShortcutIcon = it.getEditorGen().getDiagram().generateShortcutIcon();
      if (_generateShortcutIcon) {
        _builder.append("else if (navigatorGroup.getParent() instanceof org.eclipse.core.runtime.IAdaptable) {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("navigatorView = (org.eclipse.gmf.runtime.notation.View) ((org.eclipse.core.runtime.IAdaptable) navigatorGroup.getParent()).getAdapter(org.eclipse.gmf.runtime.notation.View.class);");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    return _builder;
  }
  
  public CharSequence diagramEditorClassFQName(final GenNavigator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.gmf.runtime.diagram.ui.parts.DiagramEditor");
    return _builder;
  }
}
